@@ -24,11 +24,7 @@
 #define GTK_SOURCE_COMPLETION_H
 
 #if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
-#  if defined (__GNUC__)
-#    warning "Only <gtksourceview/gtksource.h> can be included directly."
-#  elif defined (G_OS_WIN32)
-#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
-#  endif
+#error "Only <gtksourceview/gtksource.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
@@ -68,7 +64,7 @@ typedef struct _GtkSourceCompletionClass GtkSourceCompletionClass;
  * An error code used with %GTK_SOURCE_COMPLETION_ERROR in a #GError returned
  * from a completion-related function.
  */
-typedef enum
+typedef enum _GtkSourceCompletionError
 {
 	GTK_SOURCE_COMPLETION_ERROR_ALREADY_BOUND = 0,
 	GTK_SOURCE_COMPLETION_ERROR_NOT_BOUND
@@ -101,6 +97,8 @@ struct _GtkSourceCompletionClass
 							 GtkScrollStep                step,
 							 gint                         num);
 	void		(* activate_proposal)		(GtkSourceCompletion         *completion);
+
+	gpointer padding[20];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
@@ -142,10 +140,6 @@ GtkSourceCompletionContext *
 		 gtk_source_completion_create_context		(GtkSourceCompletion           *completion,
 		 						 GtkTextIter                   *position);
 
-GTK_SOURCE_DEPRECATED_IN_3_8_FOR (gtk_source_completion_provider_get_start_iter)
-void		 gtk_source_completion_move_window		(GtkSourceCompletion           *completion,
-								 GtkTextIter                   *iter);
-
 GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_completion_block_interactive	(GtkSourceCompletion           *completion);
 
