@@ -373,124 +373,6 @@ gtk_source_completion_item_init (GtkSourceCompletionItem *item)
 	item->priv = gtk_source_completion_item_get_instance_private (item);
 }
 
-/**
- * gtk_source_completion_item_new:
- * @label: The item label.
- * @text: The item text.
- * @icon: (nullable): The item icon.
- * @info: (nullable): The item extra information.
- *
- * Create a new #GtkSourceCompletionItem with label @label, icon @icon and
- * extra information @info. Both @icon and @info can be %NULL in which case
- * there will be no icon shown and no extra information available.
- *
- * Returns: a new #GtkSourceCompletionItem.
- * Deprecated: 3.24: Use gtk_source_completion_item_new2() instead.
- */
-GtkSourceCompletionItem *
-gtk_source_completion_item_new (const gchar *label,
-				const gchar *text,
-				GdkPixbuf   *icon,
-				const gchar *info)
-{
-	return g_object_new (GTK_SOURCE_TYPE_COMPLETION_ITEM,
-			     "label", label,
-			     "text", text,
-			     "icon", icon,
-			     "info", info,
-			     NULL);
-}
-
-/**
- * gtk_source_completion_item_new_with_markup:
- * @markup: The item markup label.
- * @text: The item text.
- * @icon: (nullable): The item icon.
- * @info: (nullable): The item extra information.
- *
- * Create a new #GtkSourceCompletionItem with markup label @markup, icon
- * @icon and extra information @info. Both @icon and @info can be %NULL in
- * which case there will be no icon shown and no extra information available.
- *
- * Returns: a new #GtkSourceCompletionItem.
- * Deprecated: 3.24: Use gtk_source_completion_item_new2() instead.
- */
-GtkSourceCompletionItem *
-gtk_source_completion_item_new_with_markup (const gchar *markup,
-                                            const gchar *text,
-                                            GdkPixbuf   *icon,
-                                            const gchar *info)
-{
-	return g_object_new (GTK_SOURCE_TYPE_COMPLETION_ITEM,
-			     "markup", markup,
-			     "text", text,
-			     "icon", icon,
-			     "info", info,
-			     NULL);
-}
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
-
-/**
- * gtk_source_completion_item_new_from_stock:
- * @label: (nullable): The item label.
- * @text: The item text.
- * @stock: The stock icon.
- * @info: (nullable): The item extra information.
- *
- * Creates a new #GtkSourceCompletionItem from a stock item. If @label is %NULL,
- * the stock label will be used.
- *
- * Returns: a new #GtkSourceCompletionItem.
- * Deprecated: 3.10: Use gtk_source_completion_item_new2() instead.
- */
-GtkSourceCompletionItem *
-gtk_source_completion_item_new_from_stock (const gchar *label,
-					   const gchar *text,
-					   const gchar *stock,
-					   const gchar *info)
-{
-	GtkSourceCompletionItem *item;
-	GdkPixbuf *icon;
-	GtkIconTheme *theme;
-	gint width;
-	gint height;
-	GtkStockItem stock_item;
-
-	if (stock != NULL)
-	{
-		theme = gtk_icon_theme_get_default ();
-
-		gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height);
-
-		icon = gtk_icon_theme_load_icon (theme,
-						 stock,
-						 width,
-						 GTK_ICON_LOOKUP_USE_BUILTIN,
-						 NULL);
-
-		if (label == NULL && gtk_stock_lookup (stock, &stock_item))
-		{
-			label = stock_item.label;
-		}
-	}
-	else
-	{
-		icon = NULL;
-	}
-
-	item = gtk_source_completion_item_new (label, text, icon, info);
-
-	if (icon != NULL)
-	{
-		g_object_unref (icon);
-	}
-
-	return item;
-}
-
-G_GNUC_END_IGNORE_DEPRECATIONS;
-
 /**
  * gtk_source_completion_item_new2:
  *
