@@ -23,11 +23,7 @@
 #define GTK_SOURCE_SEARCH_CONTEXT_H
 
 #if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
-#  if defined (__GNUC__)
-#    warning "Only <gtksourceview/gtksource.h> can be included directly."
-#  elif defined (G_OS_WIN32)
-#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
-#  endif
+#error "Only <gtksourceview/gtksource.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
@@ -72,10 +68,6 @@ GtkSourceBuffer		*gtk_source_search_context_get_buffer			(GtkSourceSearchContext
 GTK_SOURCE_AVAILABLE_IN_3_10
 GtkSourceSearchSettings	*gtk_source_search_context_get_settings			(GtkSourceSearchContext	 *search);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
-void			 gtk_source_search_context_set_settings			(GtkSourceSearchContext  *search,
-										 GtkSourceSearchSettings *settings);
-
 GTK_SOURCE_AVAILABLE_IN_3_10
 gboolean		 gtk_source_search_context_get_highlight		(GtkSourceSearchContext  *search);
 
@@ -101,12 +93,6 @@ gint			 gtk_source_search_context_get_occurrence_position	(GtkSourceSearchContex
 										 const GtkTextIter	 *match_start,
 										 const GtkTextIter	 *match_end);
 
-GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_forward2)
-gboolean		 gtk_source_search_context_forward			(GtkSourceSearchContext	 *search,
-										 const GtkTextIter	 *iter,
-										 GtkTextIter		 *match_start,
-										 GtkTextIter		 *match_end);
-
 GTK_SOURCE_AVAILABLE_IN_3_22
 gboolean		 gtk_source_search_context_forward2			(GtkSourceSearchContext *search,
 										 const GtkTextIter      *iter,
@@ -121,13 +107,6 @@ void			 gtk_source_search_context_forward_async		(GtkSourceSearchContext	 *searc
 										 GAsyncReadyCallback	  callback,
 										 gpointer		  user_data);
 
-GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_forward_finish2)
-gboolean		 gtk_source_search_context_forward_finish		(GtkSourceSearchContext	 *search,
-										 GAsyncResult		 *result,
-										 GtkTextIter		 *match_start,
-										 GtkTextIter		 *match_end,
-										 GError		        **error);
-
 GTK_SOURCE_AVAILABLE_IN_3_22
 gboolean		 gtk_source_search_context_forward_finish2		(GtkSourceSearchContext  *search,
 										 GAsyncResult            *result,
@@ -136,12 +115,6 @@ gboolean		 gtk_source_search_context_forward_finish2		(GtkSourceSearchContext  *
 										 gboolean                *has_wrapped_around,
 										 GError                 **error);
 
-GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_backward2)
-gboolean		 gtk_source_search_context_backward			(GtkSourceSearchContext	 *search,
-										 const GtkTextIter	 *iter,
-										 GtkTextIter		 *match_start,
-										 GtkTextIter		 *match_end);
-
 GTK_SOURCE_AVAILABLE_IN_3_22
 gboolean		 gtk_source_search_context_backward2			(GtkSourceSearchContext *search,
 										 const GtkTextIter      *iter,
@@ -156,13 +129,6 @@ void			 gtk_source_search_context_backward_async		(GtkSourceSearchContext	 *sear
 										 GAsyncReadyCallback	  callback,
 										 gpointer		  user_data);
 
-GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_backward_finish2)
-gboolean		 gtk_source_search_context_backward_finish		(GtkSourceSearchContext	 *search,
-										 GAsyncResult		 *result,
-										 GtkTextIter		 *match_start,
-										 GtkTextIter		 *match_end,
-										 GError		        **error);
-
 GTK_SOURCE_AVAILABLE_IN_3_22
 gboolean		 gtk_source_search_context_backward_finish2		(GtkSourceSearchContext  *search,
 										 GAsyncResult            *result,
@@ -171,14 +137,6 @@ gboolean		 gtk_source_search_context_backward_finish2		(GtkSourceSearchContext
 										 gboolean                *has_wrapped_around,
 										 GError                 **error);
 
-GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_replace2)
-gboolean		 gtk_source_search_context_replace			(GtkSourceSearchContext	 *search,
-										 const GtkTextIter	 *match_start,
-										 const GtkTextIter	 *match_end,
-										 const gchar		 *replace,
-										 gint			  replace_length,
-										 GError			**error);
-
 GTK_SOURCE_AVAILABLE_IN_3_22
 gboolean		 gtk_source_search_context_replace2			(GtkSourceSearchContext  *search,
 										 GtkTextIter             *match_start,
